prog='dbmapreduce'
args='-S --test-parallelism --prepend-key --parallelism=1 -K -k experiment -- perl TEST/dbmapreduce_limited_parallelism.pl'
cmp='diff -cb '
altcmp='dbfilediff --quiet -E --exit '
altcmp_needs_input_flags=true
